==> nis-1.20-1.tar.gz: nis-1.20/ypserv-0.18/system.h <==
/*  LAST EDIT: Thu Mar 14 19:26:03 1996 by Thorsten Kukuk (kukuk)  */

#if (defined(__sun__) || defined(sun)) && !defined(__svr4__)

/* Stupid SunOS 4 doesn't have prototypes in the header files */

/* Some includes just to make the compiler be quiet */
#include <stdio.h>
#include <stdarg.h>
#include <syslog.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/time.h>
#include <sys/wait.h>
#include <sys/resource.h>

extern int fprintf(FILE *, const char *, ...);
extern int fscanf(FILE *, const char *, ...);
extern int fclose(FILE *);
extern int _flsbuf(unsigned char c, FILE *fp);
extern int puts(const char *str);
extern int printf(const char *format, ...);
extern int vfprintf( FILE *stream, char  *format,  va_list ap);
extern int vsyslog(int type, char *format, va_list ap);
extern int syslog(int, const char *format, ...);
extern void openlog( char *ident, int option, int  facility);
extern char *strerror(int errnum);
extern int rename(char *path1, char *patht2);
extern char tolower(char c);

extern int chdir(const char *path);
extern int perror(const char *str);
extern int atoi(const char *str);
extern int gettimeofday(struct timeval *tp, struct timezone *tpz);
extern int gethostname(char *buf, int bufsize);

extern int socket (int af, int type, int protocol);
extern int bind (int s, struct sockaddr *name, int namelen);
extern int chdir (const char *path);
extern int select(int  n,  fd_set  *readfds,  fd_set  *writefds,
		  fd_set *exceptfds, struct timeval *timeout);
extern pid_t wait3(int *status, int options, struct rusage *rusage);
extern pid_t wait4(pid_t pid, int *status, int options, struct rusage *rusage);

#endif

#if (defined(__sun__) || defined(sun)) && defined(__svr4__)

#define __EXTENSIONS__
#define NEED_SVCSOC_H

#endif

#ifndef inline
#define inline __inline__
#endif


#if defined(hpux) || defined(__hpux__)

/* HP is really... Ah well. */

#define _INCLUDE_HPUX_SOURCE
#define _INCLUDE_XOPEN_SOURCE
#define _INCLUDE_POSIX_SOURCE
#define _INCLUDE_AES_SOURCE

extern void svcerr_systemerr();
#endif

#if defined(linux) || defined(__linux__)

/* Need this because some header files doesn't check for __linux__ */
#if !defined(linux)
#define linux linux
#endif

/* Needed for non-ANSI prototypes */
#define _SVID_SOURCE

/* Needed for gethostname() */
#define _BSD_SOURCE
#define __USE_GNU


/* xdr_domainname in Linux libc < 5.3.6 is really broken, so
   all functions in libc, which call them, too */
#define HAVE_BROKEN_LINUX_LIBC 1

extern struct hostent *_dns_gethostbyname(const char *);
extern struct hostent *_dns_gethostbyaddr(const char *, int, int);

extern int snprintf (char *, unsigned int, const char *, ...);

#else

/*
** Only Linux has a _dns_gethostbyname, for other OS, we must
** use the libc or resolv+ version
*/
#define _dns_gethostbyname gethostbyname
#define _dns_gethostbyaddr gethostbyaddr

#endif

==> nis_2.00.orig.tar.gz: nis-2.00.orig/ypserv-1.0.4/system.h <==
#if (defined(__sun__) || defined(sun)) && !defined(__svr4__)

/* Stupid SunOS 4 doesn't have prototypes in the header files */

/* Some includes just to make the compiler be quiet */
#include <stdio.h>
#include <stdarg.h>
#include <syslog.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/time.h>
#include <sys/wait.h>
#include <sys/resource.h>

extern int fprintf(FILE *, const char *, ...);
extern int fscanf(FILE *, const char *, ...);
extern int fclose(FILE *);
extern int _flsbuf(unsigned char c, FILE *fp);
extern int puts(const char *str);
extern int printf(const char *format, ...);
extern int vfprintf( FILE *stream, char  *format,  va_list ap);
extern int vsyslog(int type, char *format, va_list ap);
extern int syslog(int, const char *format, ...);
extern void openlog( char *ident, int option, int  facility);
extern char *strerror(int errnum);
extern int rename(char *path1, char *patht2);
extern char tolower(char c);

extern int chdir(const char *path);
extern int perror(const char *str);
extern int atoi(const char *str);
extern int gettimeofday(struct timeval *tp, struct timezone *tpz);
extern int gethostname(char *buf, int bufsize);

extern int socket (int af, int type, int protocol);
extern int bind (int s, struct sockaddr *name, int namelen);
extern int chdir (const char *path);
extern int select(int  n,  fd_set  *readfds,  fd_set  *writefds,
		  fd_set *exceptfds, struct timeval *timeout);
extern pid_t wait3(int *status, int options, struct rusage *rusage);
extern pid_t wait4(pid_t pid, int *status, int options, struct rusage *rusage);

#endif

#if (defined(__sun__) || defined(sun)) && defined(__svr4__)

#define __EXTENSIONS__
#define NEED_SVCSOC_H

#endif

#ifndef inline
#define inline __inline__
#endif


#if defined(hpux) || defined(__hpux__)

/* HP is really... Ah well. */

#define _INCLUDE_HPUX_SOURCE
#define _INCLUDE_XOPEN_SOURCE
#define _INCLUDE_POSIX_SOURCE
#define _INCLUDE_AES_SOURCE

extern void svcerr_systemerr();
#endif

#if defined(linux) || defined(__linux__)

/* Need this because some header files doesn't check for __linux__ */
#if !defined(linux)
#define linux linux
#endif

/* Needed for non-ANSI prototypes */
#define _SVID_SOURCE

/* Needed for gethostname() */
#define _BSD_SOURCE
#define __USE_GNU


/* xdr_domainname in Linux libc 5.x.x is really broken, so
** all functions in libc, which call them, too.
** But why is it broken with libc 5.x.x and NYS support, too ??
*/
#define HAVE_BROKEN_LINUX_LIBC 1 

/*
** Linux has a _dns_gethostbyname in a libc with NYS support,
** or in dns_hosts.c
*/
extern struct hostent *_dns_gethostbyname(const char *);
extern struct hostent *_dns_gethostbyaddr(const char *, int, int);

extern int snprintf (char *, unsigned int, const char *, ...);

#else

#if !defined(HAVE__DNS_GETHOSTBYNAME)
/*
** Only Linux has a _dns_gethostbyname so far as I know, 
** for other OS, we must use the libc or resolv+ version
*/
#define _dns_gethostbyname gethostbyname
#define _dns_gethostbyaddr gethostbyaddr

#endif

#endif
